﻿/*===========================================
    Backgrounds for this sample are powered by ThinkGeo Cloud Maps and require
    a Client ID and Secret. These were sent to you via email when you signed up
    with ThinkGeo, or you can register now at https://cloud.thinkgeo.com.
===========================================*/

using System;
using System.Collections.ObjectModel;
using System.Windows.Forms;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WinForms;

namespace HelloWorld
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.Meter;
            winformsMap1.CurrentExtent = new RectangleShape(-13086298.60, 7339062.72, -8111177.75, 2853137.62);

            ShapeFileFeatureLayer shapeFileFeatureLayer = new ShapeFileFeatureLayer(@"Countries02.shp", GeoFileReadWriteMode.Read);
            shapeFileFeatureLayer.FeatureSource.Projection = new UnmanagedProj4Projection(4326, 32615);
            //shapeFileFeatureLayer.FeatureSource.Projection = new UnmanagedProj4Projection(4326, 3857);

            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 233, 232, 214), GeoColor.FromArgb(255, 118, 138, 69));
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            InMemoryFeatureLayer imfl = new InMemoryFeatureLayer();

            GeoColor startColor = GeoColor.StandardColors.Red;
            GeoColor endColor = GeoColor.StandardColors.Blue;
            Collection<GeoColor> colors = GeoColor.GetColorsInQualityFamily(startColor, endColor, 50, ColorWheelDirection.Clockwise);
            ClassBreakStyle nearClass = new ClassBreakStyle("Value");
            for (int i = 0; i < 50; i++)
            {                
                PointStyle ps = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(colors[i]), 20);
                nearClass.ClassBreaks.Add(new ClassBreak(i, ps));
            }

            ZoomLevelSet zooms = new ZoomLevelSet();
            foreach (ZoomLevel level in winformsMap1.ZoomLevelSet.GetZoomLevels())
            {
                ZoomLevel clevel = new ZoomLevel(level.Scale);
                clevel.CustomStyles.Add(nearClass);
                zooms.CustomZoomLevels.Add(clevel);
            }

            imfl.ZoomLevelSet = zooms;
            imfl.FeatureSource.Projection = new UnmanagedProj4Projection(32615, 32615);

            Random rnd = new Random();

            for (int i = 0; i < 5000; i++)
            {
                double x = rnd.Next(-10000, 10000);
                double y = rnd.Next(-10000, 10000);
                PointShape p = new PointShape(x, y);
                imfl.InternalFeatures.Add(new Feature(p, new string[] { "Value:" + rnd.Next(0, 50) }));
            }

            imfl.Open();
            RectangleShape rect = imfl.GetBoundingBox();
            imfl.Close();

            winformsMap1.CurrentExtent = rect;

            NativeImageRasterLayer image = new NativeImageRasterLayer(@"..\..\..\ScreenShot.png", rect);            
            image.ImageSource.Projection = new UnmanagedProj4Projection(32615, 32615);

            LayerOverlay layerOverlay = new LayerOverlay();
            LayerOverlay lo = new LayerOverlay();
            
            layerOverlay.Layers.Add(shapeFileFeatureLayer);
            
            //lo.Layers.Add(image);
            lo.Layers.Add(imfl);
            
            winformsMap1.Overlays.Add(layerOverlay);
            winformsMap1.Overlays.Add(lo);
            winformsMap1.Refresh();
        }
    }
}
